@@ -94,6 +94,8 @@ private Q_SLOTS:
         }
 
         m_engine.clear();
+        QFile inFile(inputFile);
+        QVERIFY(inFile.open(QFile::ReadOnly));
 
         QFile cf(contextFile);
         KMime::Message contextMsg;
@@ -101,13 +103,16 @@ private Q_SLOTS:
             contextMsg.setContent(cf.readAll());
             contextMsg.parse();
             m_engine.setContext(&contextMsg);
+        } else if (inputFile.endsWith(QLatin1String(".eml"))) {
+            contextMsg.setContent(inFile.readAll());
+            inFile.seek(0);
+            contextMsg.parse();
+            m_engine.setContext(&contextMsg);
         } else {
             m_engine.setContext(nullptr);
             m_engine.setContextDate(QDateTime({2018, 1, 1}, {0, 0}));
         }
 
-        QFile inFile(inputFile);
-        QVERIFY(inFile.open(QFile::ReadOnly));
         m_engine.setData(inFile.readAll(), inputFile);
         auto jsonResult = m_engine.extract();
 
