@@ -35,14 +35,8 @@ using namespace KItinerary;
 enum {
     MaxPageCount = 10, // maximum in the current test set is 6
     MaxFileSize = 4000000, // maximum in the current test set is 980kB
-    // unit is pixels, assuming landscape orientation
-    MinSourceImageHeight = 10,
-    MinSourceImageWidth = 30,
-    // OEBB uses 1044x1044 for its UIC 918.3 Aztec code
-    MaxSourceImageHeight = 1100, // TODO what's a realistic value here?
-    MaxSourceImageWidth = 2000,
     // unit is 1/72 inch, assuming landscape orientation
-    MinTargetImageHeight = 30,
+    MinTargetImageHeight = 28,
     MinTargetImageWidth = 72,
     MaxTargetImageHeight = 252,
     MaxTargetImageWidth = 252,
@@ -51,6 +45,11 @@ enum {
 GenericPdfExtractor::GenericPdfExtractor() = default;
 GenericPdfExtractor::~GenericPdfExtractor() = default;
 
+void GenericPdfExtractor::setBarcodeDecoder(BarcodeDecoder *decoder)
+{
+    m_barcodeDecoder = decoder;
+}
+
 void GenericPdfExtractor::setContextDate(const QDateTime &dt)
 {
     m_contextDate = dt;
@@ -72,29 +71,18 @@ void GenericPdfExtractor::extract(PdfDocument *doc, QJsonArray &result)
 
         for (int j = 0; j < page.imageCount(); ++j) {
             const auto img = page.image(j);
-            if (m_imageIds.find(img.objectId()) != m_imageIds.end()) {
+            if (img.hasObjectId() &&  m_imageIds.find(img.objectId()) != m_imageIds.end()) {
                 continue;
             }
 
-            // image source size sanity checks
-            if (std::min(img.sourceWidth(), img.sourceHeight()) < MinSourceImageHeight
-             || std::max(img.sourceWidth(), img.sourceHeight()) < MinSourceImageWidth
-             || img.sourceHeight() > MaxSourceImageHeight
-             || img.sourceWidth() > MaxSourceImageWidth) {
-                continue;
-            }
-
-            // image target size checks
-            const auto targetRect = img.transform().map(QRectF(0, 0, 1, -1)).boundingRect();
-            if (std::min(targetRect.width(), targetRect.height()) < MinTargetImageHeight
-             || std::max(targetRect.width(), targetRect.height()) < MinTargetImageWidth
-             || targetRect.height() > MaxTargetImageHeight
-             || targetRect.width() > MaxTargetImageWidth) {
+            if (!maybeBarcode(img)) {
                 continue;
             }
 
             extractImage(img, result);
-            m_imageIds.insert(img.objectId());
+            if (img.hasObjectId()) {
+                m_imageIds.insert(img.objectId());
+            }
         }
     }
 }
@@ -106,24 +94,16 @@ QStringList GenericPdfExtractor::unrecognizedBarcodes() const
 
 void GenericPdfExtractor::extractImage(const PdfImage &img, QJsonArray &result)
 {
-    const auto aspectRatio = img.width() < img.height() ?
-        (float)img.height() / (float)img.width() :
-        (float)img.width() / (float)img.height();
-
-    // almost square, assume Aztec (or QR, which we don't handle here yet)
-    if (aspectRatio < 1.2f) {
-        const auto b = BarcodeDecoder::decodeAztecBinary(img.image());
-        if (Uic9183Parser::maybeUic9183(b)) {
-            GenericUic918Extractor::extract(b, result, m_contextDate);
-        } else {
-            extractBarcode(QString::fromUtf8(b), result);
-        }
+    const auto b = m_barcodeDecoder->decodeBinary(img.image());
+    if (Uic9183Parser::maybeUic9183(b)) {
+        GenericUic918Extractor::extract(b, result, m_contextDate);
+        return;
     }
 
-    // rectangular with medium aspect ratio, assume PDF 417
-    if (aspectRatio > 1.5 && aspectRatio < 6) {
-        const auto s = BarcodeDecoder::decodePdf417(img.image());
-        extractBarcode(s, result);
+    if (b.isEmpty()) {
+        extractBarcode(m_barcodeDecoder->decodeString(img.image()), result);
+    } else {
+        extractBarcode(QString::fromUtf8(b), result);
     }
 }
 
@@ -137,3 +117,20 @@ void GenericPdfExtractor::extractBarcode(const QString &code, QJsonArray &result
 
     m_unrecognizedBarcodes.push_back(code);
 }
+
+bool GenericPdfExtractor::maybeBarcode(const PdfImage &img, BarcodeDecoder::BarcodeTypes hint)
+{
+    const auto w = img.width();
+    const auto h = img.height();
+
+    if (!BarcodeDecoder::isPlausibleSize(img.sourceWidth(), img.sourceHeight()) || !BarcodeDecoder::isPlausibleAspectRatio(w, h, hint)) {
+        return false;
+    }
+
+    // image target size checks
+    if (std::min(w, h) < MinTargetImageHeight || std::max(w, h) < MinTargetImageWidth || h > MaxTargetImageHeight || w > MaxTargetImageWidth) {
+        return false;
+    }
+
+    return true;
+}
